import { View, Button, Slot, Picker, Input, ScrollView } from '@tarojs/components'
import Taro, { useRouter } from '@tarojs/taro';
import { useState, useEffect } from 'react';
import Form from '@/components/Form';
import FieldLabel from '@/components/Form/FieldLabel'
import { addDogInfo, getDogInfo, getDogType, setDogInfo } from '@/services/dogAPI';
import { useModel } from '@/store'
import { handleFile } from '@/utils/request';
import './style.less'

const rules = {
  name: [{ required: true, message: '请填写狗狗名称' }],
  sex: [{ type: 'number', required: true, message: '请填写狗狗性别' }],
  birthday: [{ required: true, message: '请选择狗狗生日' }],
  color: [{ required: true, message: '请选择狗狗毛色' }],
  petType: [{ required: true, message: '请选择犬种类别' }],
  image: [{ required: true, message: '请上传狗狗照片' }],
}

export default (props) => {
  const {dogs, setDogs} = useModel('userData')
  const [dogDate, setDogDate] = useState({ birthday: '请选择生日', sex: '请选择性别', petType: '请选择犬种' })
  const [dogType, setDogType] = useState([])
  const [formData, setFormData] = useState()

  const router = useRouter()
  const petId = router.params.petId

  useEffect(() => {
    getDogType().then((res) => {
      const DogTypelist = res.content.split(',').map(x => ({ text: x, value: x }))
      setDogType(DogTypelist)
    })

    if (petId) {
      getDogInfo(petId).then((e) => {
        setFormData(e)
        setDogDate(e)
      })
    }
    return;
  }, [petId])

  const formSubmit = (value) => {
    console.log('formVlue', value);
    if (petId) {
      console.log('y ID',);
      setDogInfo(petId, value).then((e) => {
        Taro.showToast({
          title: '修改成功',
          icon: 'none',
          duration: 1000
        })
        setTimeout(() => {
          Taro.navigateBack({
            delta: 1
          })
        }, 600);
      })
    } else {
      console.log('没有ID',);
      addDogInfo(value).then((e) => {
        setDogs((dogs || []).concat(e))

        Taro.showToast({
          title: '保存成功',
          icon: 'none',
          duration: 1000
        })
        setTimeout(() => {
          Taro.navigateBack({
            delta: 1
          })
        }, 600);

      })
    }
  }

  const dogSex = [
    {
      value: 1,
      text: '雄',
    },
    {
      value: 2,
      text: '雌',
    },
  ]

  const handleBirthday = (e) => {
    const birthday = e.detail.value
    setFormData({ ...formData, birthday })
  }
  
  return (
    <ScrollView scrollY style={{ height: '100vh' }}>
      <View class='page' >
        <Form rules={rules} onSubmit={formSubmit}>
          <mp-form>
            <mp-cells>
              <mp-cell>
                <Slot name='title'><FieldLabel required>狗狗名称</FieldLabel></Slot>
                <Input name='name' value={formData?.name} placeholder='请输入狗狗名称' />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>狗狗性别</FieldLabel></Slot>
                <s-picker name='sex' rangeKey='text' rangeValue='value' range={dogSex} value={formData?.sex} />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>犬种</FieldLabel></Slot>
                <s-picker name='petType' rangeKey='text' rangeValue='value' range={dogType} value={formData?.petType} />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>生日</FieldLabel></Slot>
                <Picker name='birthday' mode='date' onChange={handleBirthday}>
                  { formData?.birthday ? (
                    <View className='picker'>
                      {formData?.birthday }
                    </View>
                    ) : <View style={{ color: '#858585' }}>请选择...</View>
                  }
                </Picker>
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>毛色</FieldLabel></Slot>
                <Input name='color' placeholder='请输入毛色' value={formData?.color} />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>狗狗照片</FieldLabel></Slot>
                <uploader name='image' value={formData?.image} onFile={handleFile} />
              </mp-cell>
            </mp-cells>
          </mp-form>
          <View slot='button' style={{ margin: '4em 0 2em 0' }}>
            <Button style={{ backgroundColor: '#fbd804', borderRadius: '40px', color: '#000', border: '0px' }} class='weui-btn' type='primary' loading={false} formType='submit'>确定</Button>
          </View>
        </Form>
      </View>
    </ScrollView >
  )
}
