import { View, Button, Slot, Input, ScrollView } from '@tarojs/components'
import Taro from '@tarojs/taro';
import { useEffect, useState } from 'react';
import { setPersons } from '@/services/dogAPI';
import { useModel } from '@/store';
import { handleFile } from '@/utils/request';
import Form from '@/components/Form';
import FieldLabel from '@/components/Form/FieldLabel';

import './style.less'

const rules = {
  nickName: [{ required: true, message: '请填写姓名' }],
  sex: [{ type: 'number', required: true, message: '请选择性别' }],
  phone: [{ required: true, message: '请填写手机号' }, { len: 11, message: '请输入11位手机号' }],
  idCard: [{ required: true, message: '请填写身份证号码' }, { len: 18, message: '请输入18位身份证号码' }],
  cardImg1: [{ required: true, message: '请上传身份证照片' }],
}

export default (props) => {
  const { setPerson, person } = useModel('userData')
  // const [imgUrl, setImgUrl] = useState()
  const [userInfo, setUserInfo] = useState({ cardImg1: null, sex: '请选择性别' })
  useEffect(() => {
    if (person) {
      setUserInfo(person)
    }
  }, [person])

  const userSex = [
    {
      value: 1,
      text: '男',
    },
    {
      value: 2,
      text: '女',
    },

  ]

  const formSubmit = e => {
    const formData = e
    console.log(e)
    // // setPerson
    setPersons({ ...userInfo, ...formData, }).then((e) => {
      console.log('e', e);
      setPerson(e)
      Taro.showToast({
        title: '保存成功',
        icon: 'none',
        duration: 1000
      })
      setTimeout(() => {
        Taro.navigateBack({
          delta: 1
        })
      }, 600);
    })
  }

  return (
    <ScrollView scrollY style={{ height: '100vh' }}>
      <View class='page' >
        <Form rules={rules} onSubmit={formSubmit}>
          <mp-form>
            <mp-cells>
              <mp-cell>
                <Slot name='title'><FieldLabel required>姓名</FieldLabel></Slot>
                <Input name='nickName' placeholder='请输入姓名' value={person?.nickName} />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>性别</FieldLabel></Slot>
                <s-picker name='sex' rangeKey='text' rangeValue='value' range={userSex} value={person?.sex} />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>手机号</FieldLabel></Slot>
                <Input name='phone' type='number' placeholder='请输入手机号' maxlength={11} value={person?.phone} />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>身份证号</FieldLabel></Slot>
                <Input name='idCard' placeholder='请输入身份证号' type='idcard' maxlength={18} value={person?.idCard} />
              </mp-cell>
              <mp-cell>
                <Slot name='title'><FieldLabel required>身份证图片</FieldLabel></Slot>
                <uploader name='cardImg1' value={person?.cardImg1} onFile={handleFile} />
              </mp-cell>
            </mp-cells>
          </mp-form>
          <View style={{ margin: '4em 0 2em 0' }}>
            <Button style={{ backgroundColor: '#fbd804', borderRadius: '40px', color: '#000', border: '0px' }} class='weui-btn' type='primary' loading={false} formType='submit'>确定</Button>
          </View>
        </Form>
      </View>
    </ScrollView >
  )
}
